pyosmium-up-to-date - Bringing OSM files up-to-date
===================================================

Usage
-----

.. autoprogram:: pyosmium-up-to-date:get_arg_parser()
    :prog: pyosmium-up-to-date.py
